'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Image = require('@tiptap/extension-image');

const ImageResize = Image.extend({
    addAttributes() {
        return {
            src: {
                default: null,
            },
            alt: {
                default: null,
            },
            style: {
                default: 'width: 100%; height: auto; cursor: pointer;',
            },
        };
    },
    addNodeView() {
        return ({ node, editor, getPos }) => {
            const { view, options: { editable }, } = editor;
            const { src, alt, style } = node.attrs;
            const $positionContainer = document.createElement('div');
            const $container = document.createElement('div');
            const $img = document.createElement('img');
            const iconStyle = 'width: 24px; height: 24px; cursor: pointer;';
            const paintPositionContoller = () => {
                const $postionController = document.createElement('div');
                const $leftController = document.createElement('img');
                const $centerController = document.createElement('img');
                const $rightController = document.createElement('img');
                $postionController.setAttribute('style', 'position: absolute; top: 0%; left: 50%; width: 100px; height: 25px; z-index: 999; background-color: rgba(255, 255, 255, 0.7); border-radius: 4px; border: 2px solid #6C6C6C; cursor: pointer; transform: translate(-50%, -50%); display: flex; justify-content: space-between; align-items: center; padding: 0 10px;');
                $leftController.setAttribute('src', 'https://fonts.gstatic.com/s/i/short-term/release/materialsymbolsoutlined/format_align_left/default/20px.svg');
                $leftController.setAttribute('style', iconStyle);
                $centerController.setAttribute('src', 'https://fonts.gstatic.com/s/i/short-term/release/materialsymbolsoutlined/format_align_center/default/20px.svg');
                $centerController.setAttribute('style', iconStyle);
                $rightController.setAttribute('src', 'https://fonts.gstatic.com/s/i/short-term/release/materialsymbolsoutlined/format_align_right/default/20px.svg');
                $rightController.setAttribute('style', iconStyle);
                $leftController.addEventListener('click', () => {
                    $positionContainer.setAttribute('style', 'display: flex; justify-content: flex-start;');
                    $img.setAttribute('style', `${$img.style.cssText} justify-content: flex-start;`);
                });
                $centerController.addEventListener('click', () => {
                    $positionContainer.setAttribute('style', 'display: flex; justify-content: center;');
                    $img.setAttribute('style', `${$img.style.cssText} justify-content: center;`);
                });
                $rightController.addEventListener('click', () => {
                    $positionContainer.setAttribute('style', 'display: flex; justify-content: flex-end;');
                    $img.setAttribute('style', `${$img.style.cssText} justify-content: flex-end;`);
                });
                $postionController.appendChild($leftController);
                $postionController.appendChild($centerController);
                $postionController.appendChild($rightController);
                $container.appendChild($postionController);
            };
            $positionContainer.appendChild($container);
            const justifyContent = style.match(/justify-content: (.*?);/);
            $positionContainer.setAttribute('style', `display: flex; ${justifyContent === null || justifyContent === void 0 ? void 0 : justifyContent[0]}`);
            $container.setAttribute('style', `${style}`);
            $container.appendChild($img);
            $img.setAttribute('src', src);
            $img.setAttribute('alt', alt);
            $img.setAttribute('style', style);
            $img.setAttribute('draggable', 'true');
            if (!editable)
                return { dom: $img };
            const dotsPosition = [
                'top: -4px; left: -4px; cursor: nwse-resize;',
                'top: -4px; right: -4px; cursor: nesw-resize;',
                'bottom: -4px; left: -4px; cursor: nesw-resize;',
                'bottom: -4px; right: -4px; cursor: nwse-resize;',
            ];
            let isResizing = false;
            let startX, startWidth, startHeight;
            $container.addEventListener('click', () => {
                //remove remaining dots and position controller
                if ($container.childElementCount > 3) {
                    for (let i = 0; i < 5; i++) {
                        $container.removeChild($container.lastChild);
                    }
                }
                paintPositionContoller();
                $container.setAttribute('style', `position: relative; border: 1px dashed #6C6C6C; ${style} cursor: pointer;`);
                Array.from({ length: 4 }, (_, index) => {
                    const $dot = document.createElement('div');
                    $dot.setAttribute('style', `position: absolute; width: 9px; height: 9px; border: 1.5px solid #6C6C6C; border-radius: 50%; ${dotsPosition[index]}`);
                    $dot.addEventListener('mousedown', e => {
                        e.preventDefault();
                        isResizing = true;
                        startX = e.clientX;
                        startWidth = $container.offsetWidth;
                        startHeight = $container.offsetHeight;
                        const onMouseMove = (e) => {
                            if (!isResizing)
                                return;
                            const deltaX = index % 2 === 0 ? -(e.clientX - startX) : e.clientX - startX;
                            const aspectRatio = startWidth / startHeight;
                            const newWidth = startWidth + deltaX;
                            const newHeight = newWidth / aspectRatio;
                            $container.style.width = newWidth + 'px';
                            $container.style.height = newHeight + 'px';
                            $img.style.width = newWidth + 'px';
                            $img.style.height = newHeight + 'px';
                        };
                        const onMouseUp = () => {
                            if (isResizing) {
                                isResizing = false;
                            }
                            if (typeof getPos === 'function') {
                                const newAttrs = Object.assign(Object.assign({}, node.attrs), { style: `${$img.style.cssText}` });
                                view.dispatch(view.state.tr.setNodeMarkup(getPos(), null, newAttrs));
                            }
                            document.removeEventListener('mousemove', onMouseMove);
                            document.removeEventListener('mouseup', onMouseUp);
                        };
                        document.addEventListener('mousemove', onMouseMove);
                        document.addEventListener('mouseup', onMouseUp);
                    });
                    $container.appendChild($dot);
                });
            });
            document.addEventListener('click', (e) => {
                const $target = e.target;
                const isClickInside = $container.contains($target) || $target.style.cssText === iconStyle;
                if (!isClickInside) {
                    const containerStyle = $container.getAttribute('style');
                    const newStyle = containerStyle === null || containerStyle === void 0 ? void 0 : containerStyle.replace('border: 1px dashed #6C6C6C;', '');
                    $container.setAttribute('style', newStyle);
                    if ($container.childElementCount > 3) {
                        for (let i = 0; i < 5; i++) {
                            $container.removeChild($container.lastChild);
                        }
                    }
                }
            });
            return {
                dom: $positionContainer,
            };
        };
    },
});

exports.ImageResize = ImageResize;
exports.default = ImageResize;
//# sourceMappingURL=index.js.map
